@@ -1,15 +1,15 @@
 
 use std::str;
 
-pub fn object(bytes: &Vec<u8>) -> (String, String) {
+pub fn object(b: &Vec<u8>) -> (String, String) {
 
-    let kl: usize = u8::from_le_bytes([bytes[0]; 1]) as usize;
+    let kl: usize = u8::from_le_bytes([b[0]; 1]) as usize;
 
-    let vi: usize = 2 + kl;
+    let vi: usize = 9 + kl;
 
-    let ks = str::from_utf8(&bytes[2..vi]).unwrap().to_string(); 
+    let ks = str::from_utf8(&b[9..vi]).unwrap().to_string(); 
 
-    let vs = str::from_utf8(&bytes[vi..bytes.len()]).unwrap().to_string();
+    let vs = str::from_utf8(&b[vi..b.len()]).unwrap().to_string();
     
     (ks, vs)
 
@@ -27,9 +27,9 @@ pub fn group(b: &Vec<u8>) -> Vec<(String, String)> {
 
         let vl: usize = u8::from_le_bytes([b[i+8]; 1]) as usize;
 
-        let vi: usize = 2 + kl;
+        let vi: usize = 9 + kl;
 
-        let ks = str::from_utf8(&b[2..vi]).unwrap().to_string();
+        let ks = str::from_utf8(&b[9..vi]).unwrap().to_string();
 
         let vs = str::from_utf8(&b[vi..vi + vl]).unwrap().to_string();
         
